@@ -19,13 +19,13 @@ from warnings import warn
 from pyspark import keyword_only
 from ai.h2o.sparkling import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
-from ai.h2o.sparkling.ml.algos.H2OSupervisedAlgorithm import H2OSupervisedAlgorithm
+from ai.h2o.sparkling.ml.algos.H2OSupervisedAlgorithmWithFoldColumn import H2OSupervisedAlgorithmWithFoldColumn
 from ai.h2o.sparkling.ml.params.H2OAutoMLParams import H2OAutoMLParams
 from ai.h2o.sparkling.ml.params.H2OCommonParams import H2OCommonParams
 from ai.h2o.sparkling.ml.algos.H2OAutoMLExtras import H2OAutoMLExtras
 
 
-class H2OAutoML(H2OAutoMLParams, H2OCommonParams, H2OSupervisedAlgorithm, H2OAutoMLExtras):
+class H2OAutoML(H2OAutoMLParams, H2OCommonParams, H2OSupervisedAlgorithmWithFoldColumn, H2OAutoMLExtras):
 
     @keyword_only
     def __init__(self,
