@@ -19,14 +19,14 @@ from warnings import warn
 from pyspark import keyword_only
 from ai.h2o.sparkling import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
-from ai.h2o.sparkling.ml.algos.H2OSupervisedAlgorithm import H2OSupervisedAlgorithm
+from ai.h2o.sparkling.ml.algos.H2OSupervisedAlgorithmWithFoldColumn import H2OSupervisedAlgorithmWithFoldColumn
 from ai.h2o.sparkling.ml.models.H2ODeepLearningMOJOModel import H2ODeepLearningMOJOModel
 from ai.h2o.sparkling.ml.params.H2ODeepLearningParams import H2ODeepLearningParams
 from ai.h2o.sparkling.ml.params.H2OCommonParams import H2OCommonParams
 from ai.h2o.sparkling.ml.algos.DistributionBasedH2OTrainFramePreparation import DistributionBasedH2OTrainFramePreparation
 
 
-class H2ODeepLearning(H2ODeepLearningParams, H2OCommonParams, H2OSupervisedAlgorithm, DistributionBasedH2OTrainFramePreparation):
+class H2ODeepLearning(H2ODeepLearningParams, H2OCommonParams, H2OSupervisedAlgorithmWithFoldColumn, DistributionBasedH2OTrainFramePreparation):
 
     @keyword_only
     def __init__(self,
