@@ -96,12 +96,14 @@ class H2OGBM(H2OGBMParams, H2OCommonParams, H2OTreeBasedSupervisedAlgorithm, Dis
                  gainsliftBins=-1,
                  customMetricFunc=None,
                  customDistributionFunc=None,
-                 exportCheckpointsDir=None):
+                 exportCheckpointsDir=None,
+                 aucType="AUTO"):
         Initializer.load_sparkling_jar()
         super(H2OGBM, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.H2OGBM", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
+        kwargs = self._updateInitKwargs(kwargs)
 
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
