@@ -15,63 +15,39 @@
 # limitations under the License.
 #
 
+from warnings import warn
+from pyspark import keyword_only
 from ai.h2o.sparkling import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
-from ai.h2o.sparkling.ml.algos.H2OSupervisedAlgoBase import H2OSupervisedAlgoBase
-from ai.h2o.sparkling.ml.models import H2OMOJOModel
-from ai.h2o.sparkling.ml.params import H2OGridSearchParams
-from pyspark import keyword_only
-from pyspark.sql import SparkSession
-from pyspark.sql.dataframe import DataFrame
+from ai.h2o.sparkling.ml.algos.H2OAlgorithm import H2OAlgorithm
+from ai.h2o.sparkling.ml.params.H2OGridSearchParams import H2OGridSearchParams
+from ai.h2o.sparkling.ml.params.H2OCommonParams import H2OCommonParams
+from ai.h2o.sparkling.ml.algos.H2OGridSearchExtras import H2OGridSearchExtras
 
 
-class H2OGridSearch(H2OGridSearchParams, H2OSupervisedAlgoBase):
+class H2OGridSearch(H2OGridSearchParams, H2OCommonParams, H2OAlgorithm, H2OGridSearchExtras):
 
     @keyword_only
     def __init__(self,
                  algo=None,
                  hyperParameters={},
-                 strategy="Cartesian",
-                 maxRuntimeSecs=0.0,
-                 maxModels=0,
-                 stoppingRounds=0,
-                 stoppingTolerance=0.001,
-                 stoppingMetric="AUTO",
                  selectBestModelBy="AUTO",
                  parallelism=1,
-                 labelCol="label",
-                 foldCol=None,
-                 weightCol=None,
-                 offsetCol=None,
-                 splitRatio=1.0,
                  seed=-1,
-                 nfolds=0,
-                 allStringColumnsToCategorical=True,
-                 columnsToCategorical=[],
-                 predictionCol="prediction",
-                 detailedPredictionCol="detailed_prediction",
-                 withDetailedPredictionCol=False,
-                 featuresCols=[],
-                 convertUnknownCategoricalLevelsToNa=False,
-                 convertInvalidNumbersToNa=False,
-                 namedMojoOutputColumns=True,
-                 **DeprecatedParams):
+                 maxModels=0,
+                 maxRuntimeSecs=0.0,
+                 stoppingRounds=0,
+                 stoppingMetric="AUTO",
+                 stoppingTolerance=0.001,
+                 strategy="Cartesian"):
         Initializer.load_sparkling_jar()
         super(H2OGridSearch, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.H2OGridSearch", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
+        kwargs = self._updateInitKwargs(kwargs)
+
+        if 'interactionPairs' in kwargs:
+            warn("Interaction pairs are not supported!")
         self._set(**kwargs)
-
-    def getGridModels(self):
-        return [H2OMOJOModel(m) for m in self._java_obj.getGridModels()]
-
-    def getGridModelsParams(self):
-        jdf = self._java_obj.getGridModelsParams()
-        sqlContext = SparkSession.builder.getOrCreate()._wrapped
-        return DataFrame(jdf, sqlContext)
-
-    def getGridModelsMetrics(self):
-        jdf = self._java_obj.getGridModelsMetrics()
-        sqlContext = SparkSession.builder.getOrCreate()._wrapped
-        return DataFrame(jdf, sqlContext)
+        self._transfer_params_to_java()
