@@ -184,7 +184,7 @@ class H2OAutoML(H2OAutoMLBaseMixin, Keyed):
 
         assert_is_type(nfolds, int)
         assert nfolds >= 0, "nfolds set to " + str(nfolds) + "; nfolds cannot be negative. Use nfolds >=2 if you want cross-valiated metrics and Stacked Ensembles or use nfolds = 0 to disable."
-        assert nfolds is not 1, "nfolds set to " + str(nfolds) + "; nfolds = 1 is an invalid value. Use nfolds >=2 if you want cross-valiated metrics and Stacked Ensembles or use nfolds = 0 to disable."
+        assert nfolds != 1, "nfolds set to " + str(nfolds) + "; nfolds = 1 is an invalid value. Use nfolds >=2 if you want cross-valiated metrics and Stacked Ensembles or use nfolds = 0 to disable."
         self.nfolds = self.build_control["nfolds"] = nfolds
 
         assert_is_type(balance_classes, bool)
@@ -627,6 +627,7 @@ def get_leaderboard(aml, extra_columns=None):
         - 'ALL': adds all columns below.
         - 'training_time_ms': column providing the training time of each model in milliseconds (doesn't include the training of cross validation models).
         - 'predict_time_per_row_ms`: column providing the average prediction time by the model for a single row.
+        - 'algo': column providing the algorithm name for each model.
     :return: An H2OFrame representing the leaderboard.
     :examples:
     >>> aml = H2OAutoML(max_runtime_secs=30)
