@@ -30,6 +30,7 @@ from h2o.utils.typechecks import assert_is_type, assert_satisfies, BoundInt, I,
 __all__ = ("H2OLocalServer", )
 
 
+
 class H2OLocalServer(object):
     """
     Handle to an H2O server launched locally.
@@ -55,7 +56,7 @@ class H2OLocalServer(object):
             # do something with the server -- probably connect to it
     """
 
-    # (Avkash) Changing the maximum time to wait as 60 seconds to match with the same time in to R API. ##
+    ## (Avkash) Changing the maximum time to wait as 60 seconds to match with the same time in to R API. ##
     _TIME_TO_START = 60  # Maximum time we wait for the server to start up (in seconds)
     _TIME_TO_KILL = 3    # Maximum time we wait for the server to shut down until we kill it (in seconds)
 
@@ -144,10 +145,12 @@ class H2OLocalServer(object):
         atexit.register(lambda: hs.shutdown())
         return hs
 
+
     def is_running(self):
         """Return True if the server process is still running, False otherwise."""
         return self._process is not None and self._process.poll() is None
 
+
     def shutdown(self):
         """
         Shut down the server by trying to terminate/kill its process.
@@ -170,6 +173,7 @@ class H2OLocalServer(object):
             pass
         self._process = None
 
+
     @property
     def scheme(self):
         """Connection scheme, 'http' or 'https'."""
@@ -190,9 +194,9 @@ class H2OLocalServer(object):
         """H2O cluster name."""
         return self._name
 
-    # ------------------------------------------------------------------------------------------------------------------
+    #-------------------------------------------------------------------------------------------------------------------
     # Private
-    # ------------------------------------------------------------------------------------------------------------------
+    #-------------------------------------------------------------------------------------------------------------------
 
     def __init__(self):
         """[Internal] please use H2OLocalServer.start() to launch a new server."""
@@ -209,6 +213,7 @@ class H2OLocalServer(object):
         self._stderr = None
         self._tempdir = None
 
+
     def _find_jar(self, path0=None):
         """
         Return the location of an h2o.jar executable.
@@ -235,8 +240,7 @@ class H2OLocalServer(object):
         own_jar = os.getenv("H2O_JAR_PATH", "")
         if own_jar != "":
             if not os.path.isfile(own_jar):
-                raise H2OStartupError("Environment variable H2O_JAR_PATH is set to '%d' but file does not exists, "
-                                      "unset environment variable or provide valid path to h2o.jar file." % own_jar)
+                raise H2OStartupError("Environment variable H2O_JAR_PATH is set to '%d' but file does not exists, unset environment variable or provide valid path to h2o.jar file." % own_jar)
             yield own_jar
 
         # Check if running from an h2o-3 src folder (or any subfolder), in which case use the freshly-built h2o.jar
@@ -263,8 +267,8 @@ class H2OLocalServer(object):
         yield os.path.join(get_config_var("userbase"), "h2o_jar", "h2o.jar")
         yield os.path.join(prefix2, "h2o_jar", "h2o.jar")
 
-    def _launch_server(self, port, baseport, mmax, mmin, ea, nthreads, jvm_custom_args, bind_to_localhost, 
-                       log_dir=None, log_level=None, max_log_file_size=None):
+
+    def _launch_server(self, port, baseport, mmax, mmin, ea, nthreads, jvm_custom_args, bind_to_localhost, log_dir=None, log_level=None, max_log_file_size=None):
         """Actually start the h2o.jar executable (helper method for `.start()`)."""
         self._ip = "127.0.0.1"
 
@@ -276,6 +280,9 @@ class H2OLocalServer(object):
             print("  Starting server from " + self._jar_path)
             print("  Ice root: " + self._ice_root)
 
+        # Combine jar path with the optional extra classpath
+        classpath = [self._jar_path] if self._extra_classpath is None else [self._jar_path] + self._extra_classpath
+
         # Construct java command to launch the process
         cmd = [java]
 
@@ -292,14 +299,7 @@ class H2OLocalServer(object):
                 assert type(arg) is str
                 cmd += [arg]
 
-        # This should be the last JVM option
-        if self._extra_classpath is None:
-            # Use jar file directly
-            cmd += ["-jar", self._jar_path]
-        else:
-            # Combine jar path with the optional extra classpath
-            classpath = [self._jar_path] + self._extra_classpath
-            cmd += ["-cp", os.pathsep.join(classpath), "water.H2OApp"]
+        cmd += ["-cp", os.pathsep.join(classpath), "water.H2OApp"]  # This should be the last JVM option
 
         # ...add H2O options
         cmd += ["-ip", self._ip]
@@ -326,14 +326,13 @@ class H2OLocalServer(object):
         # Warning: do not change to any higher log-level, otherwise we won't be able to know which port the
         # server is listening to.
         cmd += ["-log_level", "INFO"]
-        cmd += ["-allow_unsupported_java"]
 
         # Create stdout and stderr files
         self._stdout = self._tmp_file("stdout")
         self._stderr = self._tmp_file("stderr")
         cwd = os.path.abspath(os.getcwd())
-        out = open(self._stdout, "w", encoding='utf-8')
-        err = open(self._stderr, "w", encoding='utf-8')
+        out = open(self._stdout, "w")
+        err = open(self._stderr, "w")
         if self._verbose:
             print("  JVM stdout: " + out.name)
             print("  JVM stderr: " + err.name)
@@ -357,7 +356,7 @@ class H2OLocalServer(object):
                 else:
                     error_message = "Server process terminated with error code %d" % proc.returncode 
                 if os.stat(self._stderr).st_size > 0:
-                    error_message += ": %s" % open(self._stderr, encoding='utf-8').read()
+                    error_message += ": %s" % open(self._stderr).read()
                 else:
                     error_message += "."
                 raise H2OServerError(error_message)
@@ -408,9 +407,7 @@ class H2OLocalServer(object):
         if h2o_java:
             full_path = os.path.join(h2o_java, "bin", java)
             if not os.path.exists(full_path):
-                raise H2OStartupError("Environment variable H2O_JAVA_HOME is set to '%d' "
-                                      "but this location doesn't appear to be a valid Java Home directory, "
-                                      "unset environment variable or provide valid path to Java Home." % h2o_java)
+                raise H2OStartupError("Environment variable H2O_JAVA_HOME is set to '%d' but this location doesn't appear to be a valid Java Home directory, unset environment variable or provide valid path to Java Home." % h2o_java)
             return full_path
 
         # is java callable directly (doesn't work on windows it seems)?
@@ -442,7 +439,8 @@ class H2OLocalServer(object):
 
         # not found...
         raise H2OStartupError("Cannot find Java. Please install the latest JRE from\n"
-                              "http://docs.h2o.ai/h2o/latest-stable/h2o-docs/welcome.html#java-requirements")
+                              "http://www.oracle.com/technetwork/java/javase/downloads/index.html")
+
 
     def _tmp_file(self, kind):
         """
@@ -467,6 +465,7 @@ class H2OLocalServer(object):
                 self._tempdir = tempfile.mkdtemp()
             return os.path.join(self._tempdir, "h2o_%s_started_from_python.%s" % (usr, kind[3:]))
 
+
     def _get_server_info_from_logs(self):
         """
         Check server's output log, and determine its scheme / IP / port (helper method for `._launch_server()`).
@@ -479,7 +478,7 @@ class H2OLocalServer(object):
         :returns: (scheme, ip, port) tuple if the server has already started, None otherwise.
         """
         searchstr = ": Open H2O Flow in your web browser:"
-        with open(self._stdout, "rt", encoding='utf-8') as f:
+        with open(self._stdout, "rt") as f:
             for line in f:
                 if searchstr in line:
                     url = line[line.index(searchstr) + len(searchstr):].strip().rstrip("/")
@@ -489,6 +488,7 @@ class H2OLocalServer(object):
                     return parts[0], parts[1][2:], int(parts[2])
         return None
 
+
     def __enter__(self):
         return self
 
